@@ -38,17 +38,17 @@
 DefaultScriptClass::DefaultScriptClass(QScriptEngine* engine, ScriptHandlerInfo* handlerInfo)
     : QScriptClass(engine), mHandlerInfo(handlerInfo)
 {
-    s_valid = engine->toStringHandle(ParserStrings::PROPERTY_VALID);
-    s_wasAbleToRead = engine->toStringHandle(ParserStrings::PROPERTY_ABLE_TO_READ);
-    s_validationError = engine->toStringHandle(ParserStrings::PROPERTY_VALIDATION_ERROR);
-    s_parent = engine->toStringHandle(ParserStrings::PROPERTY_PARENT);
-    s_byteOrder = engine->toStringHandle(ParserStrings::PROPERTY_BYTEORDER);
-    s_name = engine->toStringHandle(ParserStrings::PROPERTY_NAME);
-    s_datatype = engine->toStringHandle(ParserStrings::PROPERTY_DATATYPE);
-    s_updateFunc = engine->toStringHandle(ParserStrings::PROPERTY_UPDATE_FUNC);
-    s_validationFunc = engine->toStringHandle(ParserStrings::PROPERTY_VALIDATION_FUNC);
-    s_customTypeName = engine->toStringHandle(ParserStrings::PROPERTY_CUSTOM_TYPE_NAME);
-    s_asStringFunc = engine->toStringHandle(ParserStrings::PROPERTY_TO_STRING_FUNC);
+    s_valid = engine->toStringHandle(ParserStrings::PROPERTY_VALID());
+    s_wasAbleToRead = engine->toStringHandle(ParserStrings::PROPERTY_ABLE_TO_READ());
+    s_validationError = engine->toStringHandle(ParserStrings::PROPERTY_VALIDATION_ERROR());
+    s_parent = engine->toStringHandle(ParserStrings::PROPERTY_PARENT());
+    s_byteOrder = engine->toStringHandle(ParserStrings::PROPERTY_BYTEORDER());
+    s_name = engine->toStringHandle(ParserStrings::PROPERTY_NAME());
+    s_datatype = engine->toStringHandle(ParserStrings::PROPERTY_DATATYPE());
+    s_updateFunc = engine->toStringHandle(ParserStrings::PROPERTY_UPDATE_FUNC());
+    s_validationFunc = engine->toStringHandle(ParserStrings::PROPERTY_VALIDATION_FUNC());
+    s_customTypeName = engine->toStringHandle(ParserStrings::PROPERTY_CUSTOM_TYPE_NAME());
+    s_asStringFunc = engine->toStringHandle(ParserStrings::PROPERTY_TO_STRING_FUNC());
 
 
     //TODO remove, every subclass should have proto
@@ -127,7 +127,7 @@ QScriptClass::QueryFlags DefaultScriptClass::queryProperty(const QScriptValue& o
     {
         data->logError() << "could not find property with name" << name.toString();
         engine()->currentContext()->throwError(QScriptContext::ReferenceError,
-                QStringLiteral("Could not find property with name ") + name.toString());
+                QLatin1String("Could not find property with name ") + name.toString());
         return 0;
     }
 }
@@ -197,7 +197,7 @@ QScriptValue DefaultScriptClass::property(const QScriptValue& object, const QScr
     {
         data->logError() << "could not find property with name" << name.toString();
         return engine()->currentContext()->throwError(QScriptContext::ReferenceError,
-                QStringLiteral("Cannot read property ") + name.toString());
+                QLatin1String("Cannot read property ") + name.toString());
     }
 }
 
@@ -353,7 +353,7 @@ void DefaultScriptClass::setProperty(QScriptValue& object, const QScriptString&
         {
             data->logError() << "could not set property with name" << name.toString();
             engine()->currentContext()->throwError(QScriptContext::ReferenceError,
-                QStringLiteral("Cannot write property ") + name.toString());
+                QLatin1String("Cannot write property ") + name.toString());
         }
     }
 }
