@@ -36,10 +36,10 @@
 //// #include "my_bytearraystreamencoder.h"
 //// NEWBYTEARRAYSTREAMENCODERCONFIGEDITORFACTORY(end)
 // Qt
-#include <QtCore/QList>
+#include <QList>
 
 
-namespace Kasten2
+namespace Kasten
 {
 
 QList<AbstractModelStreamEncoderConfigEditorFactory*> ByteArrayStreamEncoderConfigEditorFactoryFactory::createFactorys()
